@@ -26,15 +26,15 @@ function(X, minvi = .03, minsize = default.minsize){
     R[,i] <- 0
     for (j in (i+1):J){
       k <- k + 1
-      rvm <- (m-1)*(m-1)+2
+      rvm <- (m-1)*(m-1)+1
       violation.matrix <- matrix(0,nrow=rvm,ncol=8)
       dimnames(violation.matrix) <-  list(
-       c(t(outer(paste("P(X",i,">=",1:(m-1),")",sep=""),paste("P(X",j,">=",1:(m-1),")",sep=""),paste)),paste("E(X",i,") E(X",j,")", sep=""),"Total"),
+       c(t(outer(paste("P(X",i,">=",1:(m-1),")",sep=""),paste("P(X",j,">=",1:(m-1),")",sep=""),paste)),"Total"),
        c("#ac","#vi","#vi/#ac","maxvi","sum","sum/#ac","zmax","#zsig"))
       results[[k]] <- list()
       results[[k]][[1]] <- list()
-      results[[k]][[1]][1] <- I.labels[i]
-      results[[k]][[1]][2] <- I.labels[j]
+      results[[k]][[1]]$FIRST.ITEM <- I.labels[i]
+      results[[k]][[1]]$SECOND.ITEM <- I.labels[j]
       sorted.R <- sort(R[,j])
       group <- max(which(sorted.R==sorted.R[minsize]))
       repeat{
@@ -66,14 +66,21 @@ function(X, minvi = .03, minsize = default.minsize){
         summary.matrix[g,7:(5+m)] <- cum.freqi[2:m]
         summary.matrix[g,(6+m):(4+2*m)] <- cum.freqj[2:m]
       }
-      results[[k]][[2]] <- summary.matrix
+      results[[k]]$SUMMARY.MATRIX <- summary.matrix
 
       ac <- violation.matrix[1:(rvm-1),1] <- L-1
+
+      z.scores <- matrix(NA,(m-1)^2,L)
+      dimnames(z.scores) <- list(t(outer(paste("P(X",i,">=",1:(m-1),")",sep=""),paste("P(X",j,">=",1:(m-1),")",sep=""),paste)),
+                                  paste("Rest-score", apply(summary.matrix[,2:3],1,paste, collapse="-")))
+
 #      for (g in 1:(m-1)) for (h in 1:(m-1)){
 #         violation.matrix[(g-1)*(m-1)+h,2:8] <- compute.violations(summary.matrix[,6+g],summary.matrix[,5+m+h],L-1,minvi)
 #      }  
-      
+
+      hh <- 0
       for (g in 1:(m-1)) for (h in 1:(m-1)){
+        hh <- hh + 1
         p.1 <- summary.matrix[,6+g]
         p.2 <- summary.matrix[,5+m+h]
         n <- summary.matrix[,4]
@@ -87,14 +94,15 @@ function(X, minvi = .03, minsize = default.minsize){
            for (gg in 1:L){
               if(d[gg] > 0){
                  Xgg <-  X[member==gg,]
-                 f.01 <- length(Xgg[Xgg[,i] >= g & Xgg[,j] <  h])/J
-                 f.10 <- length(Xgg[Xgg[,i] <  g & Xgg[,j] >= h])/J
+                 f.01 <- length(Xgg[Xgg[,i] >= g & Xgg[,j] <  h,])/J
+                 f.10 <- length(Xgg[Xgg[,i] <  g & Xgg[,j] >= h,])/J
                  f.k <- min(f.01,f.10); f.n <- f.01 + f.10; f.b <- ((2 * f.k + 1 - f.n)^2 - 10 * f.n) /(12 * f.n)
                  z[gg] <- abs(sqrt(2*f.k + 2 + f.b) - sqrt(2*f.n-2*f.k+f.b))          
               }  
            }
         }        
         violation.matrix[(g-1)*(m-1)+h,2:8] <- c(vi,vi/(L-1),max(d),sum.vi,sum.vi/ac,max(z),length(z[abs(z) > qnorm(.95)]))
+        z.scores[hh,] <- z
       }  
 
 #     violation.matrix[(rvm-1),2:8] <- compute.violations(,summary.matrix[,6],L-1,minvi)
@@ -104,34 +112,34 @@ function(X, minvi = .03, minsize = default.minsize){
       d[d <= minvi] <- 0
       vi <- length(d[d > minvi/2])
       sum.vi <- sum(d)
-      # BEGIN NEW AANPASSEN ALS var(X[member==gg,i]) == var(X[member==gg,j]) == 0  geen t-test mogelijk.
-      T.statistic <- rep(0,L)  # T statistic
-      t.res <- list(NULL)
-      p <- rep(1,L)             # p-value
-#      if(any(d > 0)){
-        for (gg in 1:L){
-           if(d[gg] > 0){
-             t.res[[gg]] <- t.test(X[member==gg,i],X[member==gg,j],alternative="less")
-             T.statistic[gg] <- abs(t.res[[gg]]$statistic)
-             p[gg] <- t.res[[gg]]$p.value
-           } else t.res[[gg]] <- 0
-        }
-#      }
-      violation.matrix[(rvm-1),2:8] <- c(vi,vi/ac,max(d),sum.vi,sum.vi/ac,max(T.statistic),length(p[p < .05]))
-      # END NEW
+#      # BEGIN NEW AANPASSEN ALS var(X[member==gg,i]) == var(X[member==gg,j]) == 0  geen t-test mogelijk.
+#       T.statistic <- rep(0,L)  # T statistic
+#       t.res <- list(NULL)
+#       p <- rep(1,L)             # p-value
+#       if(any(d > 0)){
+#         for (gg in 1:L){
+#            if(d[gg] > 0){
+#              t.res[[gg]] <- t.test(X[member==gg,i],X[member==gg,j],alternative="less")
+#              T.statistic[gg] <- abs(t.res[[gg]]$statistic)
+#              p[gg] <- t.res[[gg]]$p.value
+#            } else t.res[[gg]] <- 0
+#         }
+#       }
+#       violation.matrix[(rvm-1),2:8] <- c(vi,vi/ac,max(d),sum.vi,sum.vi/ac,max(T.statistic),length(p[p < .05]))
+#      # END NEW
 
-      if(rvm > 3){
-         violation.matrix[rvm,c(1,2,5,8)] <- apply(violation.matrix[1:(rvm-2),c(1,2,5,8)],2,sum)
-         violation.matrix[rvm,c(4,7)] <- apply(violation.matrix[1:(rvm-2),c(4,7)],2,max)
+      if(rvm > 2){
+         violation.matrix[rvm,c(1,2,5,8)] <- apply(violation.matrix[1:(rvm-1),c(1,2,5,8)],2,sum)
+         violation.matrix[rvm,c(4,7)] <- apply(violation.matrix[1:(rvm-1),c(4,7)],2,max)
       }else{
          violation.matrix[rvm,c(1,2,4,5,7,8)] <- violation.matrix[1,c(1,2,4,5,7,8)]
       }
       violation.matrix[rvm,3] <- violation.matrix[rvm,2]/violation.matrix[rvm,1]
       violation.matrix[rvm,6] <- violation.matrix[rvm,5]/violation.matrix[rvm,1]
-      results[[k]][[3]] <- violation.matrix
-      # BEGIN TMP
-      results[[k]][[4]] <- t.res
-      # END TMP
+      results[[k]]$VIOLATION.MATRIX <- violation.matrix
+#      # BEGIN TMP
+      results[[k]]$Z.SCORES <- z.scores
+#      # END TMP
    }
  }
  Hi <- coefH(X,FALSE)$Hi
