@@ -16,16 +16,16 @@ function(x, item.pairs = all.pairs, ask = TRUE, ...){
       xlab = "Rest score group",
       ylab = "Item rest function",
       type = "n", lwd=3)
-    lines(plot.matrix[,1],plot.matrix[,5]/m, lwd=5, lty=1)
-    lines(plot.matrix[,1],plot.matrix[,6]/m, lwd=5, lty=3)
+#    lines(plot.matrix[,1],plot.matrix[,5]/m, lwd=5, lty=1)
+#    lines(plot.matrix[,1],plot.matrix[,6]/m, lwd=5, lty=3)
     title(paste(results[[j]][[1]][1],"(solid)",results[[j]][[1]][2],"(dashed)"))
     axis(1, at=1:nrow(plot.matrix),labels=x.labels)
-    if(m > 1){
+#    if(m > 1){
       for(i in 1:(m)){
         lines(plot.matrix[,1],plot.matrix[,(6+i)], col=4, lwd=2)
-        lines(plot.matrix[,1],plot.matrix[,(6+(m-1)+i)], col=4, lwd=2, lty=3)
+        lines(plot.matrix[,1],plot.matrix[,(6+(m)+i)], col=4, lwd=2, lty=3)
       }
-    }
+#    }
   }
  invisible()
 }
